==> refcodes-filesystem-1.1.3-sources.jar: org/refcodes/filesystem/UnknownNameException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.filesystem;

import org.refcodes.filesystem.FileSystemException.FileSystemNameException;

public class UnknownNameException extends FileSystemNameException {

	private static final long serialVersionUID = 1L;

	public UnknownNameException( String aName, String aMessage, String aErrorCode ) {
		super( aName, aMessage, aErrorCode );
	}

	public UnknownNameException( String aName, String aMessage, Throwable aCause, String aErrorCode ) {
		super( aName, aMessage, aCause, aErrorCode );
	}

	public UnknownNameException( String aName, String message, Throwable cause ) {
		super( aName, message, cause );
	}

	public UnknownNameException( String aName, String message ) {
		super( aName, message );
	}

	public UnknownNameException( String aName, Throwable aCause, String aErrorCode ) {
		super( aName, aCause, aErrorCode );
	}

	public UnknownNameException( String aName, Throwable cause ) {
		super( aName, cause );
	}
}

==> refcodes-filesystem-1.10.0-sources.jar: org/refcodes/filesystem/UnknownNameException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.filesystem;

import org.refcodes.filesystem.FileSystemException.FileSystemNameException;

/**
 * The Class UnknownNameException.
 */
public class UnknownNameException extends FileSystemNameException {

	private static final long serialVersionUID = 1L;

	/**
	 * Instantiates a new unknown name exception.
	 *
	 * @param aName the name
	 * @param aMessage the message
	 * @param aErrorCode the error code
	 */
	public UnknownNameException( String aName, String aMessage, String aErrorCode ) {
		super( aName, aMessage, aErrorCode );
	}

	/**
	 * Instantiates a new unknown name exception.
	 *
	 * @param aName the name
	 * @param aMessage the message
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public UnknownNameException( String aName, String aMessage, Throwable aCause, String aErrorCode ) {
		super( aName, aMessage, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new unknown name exception.
	 *
	 * @param aName the name
	 * @param message the message
	 * @param cause the cause
	 */
	public UnknownNameException( String aName, String message, Throwable cause ) {
		super( aName, message, cause );
	}

	/**
	 * Instantiates a new unknown name exception.
	 *
	 * @param aName the name
	 * @param message the message
	 */
	public UnknownNameException( String aName, String message ) {
		super( aName, message );
	}

	/**
	 * Instantiates a new unknown name exception.
	 *
	 * @param aName the name
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public UnknownNameException( String aName, Throwable aCause, String aErrorCode ) {
		super( aName, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new unknown name exception.
	 *
	 * @param aName the name
	 * @param cause the cause
	 */
	public UnknownNameException( String aName, Throwable cause ) {
		super( aName, cause );
	}
}
